[jboss-cvs] JBossAS SVN: r84753 - in projects/jboss-osgi/trunk: runtime/felix/src/test/java/org/jboss and 15 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Wed Feb 25 12:07:22 EST 2009


Author: thomas.diesler at jboss.com
Date: 2009-02-25 12:07:22 -0500 (Wed, 25 Feb 2009)
New Revision: 84753

Added:
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system/
   projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/
   projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/
   projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/jbosgi36-service.xml
   projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/jbosgi36.bnd
Removed:
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/system/
Modified:
   projects/jboss-osgi/trunk/pom.xml
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredService.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredServiceTest.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitService.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitServiceTest.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/MyBean.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system/SystemBundleTest.java
   projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/configured-service-test.xml
   projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/explicit-service-test.xml
   projects/jboss-osgi/trunk/testsuite/pom.xml
   projects/jboss-osgi/trunk/testsuite/scripts/antrun-test-jars.xml
   projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/bundle/SomeService.java
   projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/junit/JBOSGI36Test.java
   projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/Foo.java
   projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/FooMBean.java
Log:
[JBOSGI-36] Test access to private package

Modified: projects/jboss-osgi/trunk/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/pom.xml	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/pom.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -225,7 +225,8 @@
         <plugin>
           <artifactId>maven-surefire-plugin</artifactId>
           <configuration>
-            <redirectTestOutputToFile>true</redirectTestOutputToFile>
+            <redirectTestOutputToFile>false</redirectTestOutputToFile>
+            <failIfNoTests>false</failIfNoTests>
           </configuration>
         </plugin>
       </plugins>

Copied: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer (from rev 84730, projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer)


Property changes on: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer
___________________________________________________________________
Name: svn:mergeinfo
   + 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredService.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/ConfiguredService.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredService.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.microcontainer;
+package org.jboss.test.osgi.felix.microcontainer;
 
 //$Id$
 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredServiceTest.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/ConfiguredServiceTest.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ConfiguredServiceTest.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.microcontainer;
+package org.jboss.test.osgi.felix.microcontainer;
 
 //$Id$
 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitService.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/ExplicitService.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitService.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.microcontainer;
+package org.jboss.test.osgi.felix.microcontainer;
 
 //$Id$
 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitServiceTest.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/ExplicitServiceTest.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/ExplicitServiceTest.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.microcontainer;
+package org.jboss.test.osgi.felix.microcontainer;
 
 //$Id$
 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/MyBean.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/microcontainer/MyBean.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/microcontainer/MyBean.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.microcontainer;
+package org.jboss.test.osgi.felix.microcontainer;
 
 //$Id$
 

Copied: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system (from rev 84730, projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/system)


Property changes on: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system
___________________________________________________________________
Name: svn:mergeinfo
   + 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system/SystemBundleTest.java
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/osgi/test/felix/system/SystemBundleTest.java	2009-02-25 12:57:23 UTC (rev 84730)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/java/org/jboss/test/osgi/felix/system/SystemBundleTest.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
-package org.jboss.osgi.test.felix.system;
+package org.jboss.test.osgi.felix.system;
 
 //$Id$
 

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/configured-service-test.xml
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/configured-service-test.xml	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/configured-service-test.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -11,11 +11,11 @@
   <property name="kernel"><inject bean="jboss.kernel:service=Kernel" /></property>
  </bean>
 
- <bean name="MyBean" class="org.jboss.osgi.test.felix.microcontainer.MyBean">
+ <bean name="MyBean" class="org.jboss.test.osgi.felix.microcontainer.MyBean">
   <property name="bundleContext"><inject bean="jboss.osgi:service=Framework" property="systemBundleContext"/></property>
  </bean>
 
- <bean name="ConfiguredService" class="org.jboss.osgi.test.felix.microcontainer.ConfiguredService">
+ <bean name="ConfiguredService" class="org.jboss.test.osgi.felix.microcontainer.ConfiguredService">
   <property name="bundleContext"><inject bean="jboss.osgi:service=Framework" property="systemBundleContext"/></property>
   <property name="testBean"><inject bean="MyBean"/></property>
  </bean>

Modified: projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/explicit-service-test.xml
===================================================================
--- projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/explicit-service-test.xml	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/runtime/felix/src/test/resources/microcontainer/explicit-service-test.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -11,7 +11,7 @@
   <property name="kernel"><inject bean="jboss.kernel:service=Kernel" /></property>
  </bean>
 
- <bean name="MyBean" class="org.jboss.osgi.test.felix.microcontainer.MyBean">
+ <bean name="MyBean" class="org.jboss.test.osgi.felix.microcontainer.MyBean">
   <property name="bundleContext"><inject bean="jboss.osgi:service=Framework" property="systemBundleContext"/></property>
  </bean>
 

Modified: projects/jboss-osgi/trunk/testsuite/pom.xml
===================================================================
--- projects/jboss-osgi/trunk/testsuite/pom.xml	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/pom.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -94,6 +94,10 @@
               <value>${basedir}/target</value>
             </property>
           </systemProperties>
+          <excludes>
+            <!-- [JBOSGI-36] Bundle classes leak into system classloader -->
+            <exclude>org/jboss/test/osgi/jbosgi36/junit/JBOSGI36Test.java</exclude>
+          </excludes>
         </configuration>
       </plugin>
     </plugins>

Modified: projects/jboss-osgi/trunk/testsuite/scripts/antrun-test-jars.xml
===================================================================
--- projects/jboss-osgi/trunk/testsuite/scripts/antrun-test-jars.xml	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/scripts/antrun-test-jars.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -12,50 +12,56 @@
 
   <description>OSGi test archive builder</description>
 
-	  <!-- ================================================================== -->
-	  <!-- Init                                                               -->
-	  <!-- ================================================================== -->
-	
-	  <target name="init">
+  <!-- ================================================================== -->
+  <!-- Init                                                               -->
+  <!-- ================================================================== -->
 
-	  	<!-- Property override when not called from maven -->
-	    <property name="maven.runtime.classpath" value="/usr/java/bnd.jar" />
-	    <property name="tests.output.dir" value="${basedir}/../target" />
-	    	
-	  	<mkdir dir="${tests.output.dir}/test-libs" />
-	    <property name="tests.classes.dir" value="${tests.output.dir}/test-classes" />
-	    <property name="tests.resources.dir" value="${tests.output.dir}/test-classes" />
+  <target name="init">
 
-	    <taskdef resource="aQute/bnd/ant/taskdef.properties">
-	      <classpath>
-	        <pathelement path="${maven.runtime.classpath}" />
-	      </classpath>
-		</taskdef>
-	  	
-	  </target>
-	
-	  <!-- ================================================================== -->
-	  <!-- Building                                                           -->
-	  <!-- ================================================================== -->
+    <!-- Property override when not called from maven -->
+    <property name="maven.runtime.classpath" value="/usr/java/bnd.jar" />
+    <property name="tests.output.dir" value="${basedir}/../target" />
 
-	  <target name="build-test-jars" depends="init" description="Build the test deployments">
+    <mkdir dir="${tests.output.dir}/test-libs" />
+    <property name="tests.classes.dir" value="${tests.output.dir}/test-classes" />
+    <property name="tests.resources.dir" value="${tests.output.dir}/test-classes" />
 
-	    <!-- Please add alphabetically -->
-	  	
-	    <!-- jbosgi36 -->
-	  	<bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/jbosgi36-bundle.jar" 
-	  		files="${tests.resources.dir}/jbosgi36/jbosgi36.bnd"/>
+    <taskdef resource="aQute/bnd/ant/taskdef.properties">
+      <classpath>
+        <pathelement path="${maven.runtime.classpath}" />
+      </classpath>
+    </taskdef>
 
-	    <!-- http-service -->
-	  	<bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/http-service.jar" 
-	  		files="${tests.resources.dir}/service/http/http-service.bnd"/>
+  </target>
 
-	    <!-- microcontainer-service -->
-	  	<bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/microcontainer-service.jar" 
-	  		files="${tests.resources.dir}/service/microcontainer/microcontainer-service.bnd"/>
+  <!-- ================================================================== -->
+  <!-- Building                                                           -->
+  <!-- ================================================================== -->
 
-	    <!-- Please add alphabetically -->
+  <target name="build-test-jars" depends="init" description="Build the test deployments">
 
-	  </target>
+    <!-- Please add alphabetically -->
 
+    <!-- jbosgi36 -->
+    <bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/jbosgi36-bundle.jar" files="${tests.resources.dir}/jbosgi36/jbosgi36.bnd" />
+    <jar jarfile="${tests.output.dir}/test-libs/jbosgi36-service.jar">
+      <fileset dir="${tests.classes.dir}">
+        <include name="org/jboss/test/osgi/jbosgi36/mbean/Foo.class" />
+        <include name="org/jboss/test/osgi/jbosgi36/mbean/FooMBean.class" />
+      </fileset>
+      <fileset dir="${tests.resources.dir}/jbosgi36">
+        <include name="META-INF/jbosgi36-service.xml" />
+      </fileset>
+    </jar>
+
+    <!-- http-service -->
+    <bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/http-service.jar" files="${tests.resources.dir}/service/http/http-service.bnd" />
+
+    <!-- microcontainer-service -->
+    <bnd classpath="${tests.classes.dir}" output="${tests.output.dir}/test-libs/microcontainer-service.jar" files="${tests.resources.dir}/service/microcontainer/microcontainer-service.bnd" />
+
+    <!-- Please add alphabetically -->
+
+  </target>
+
 </project>

Modified: projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/bundle/SomeService.java
===================================================================
--- projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/bundle/SomeService.java	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/bundle/SomeService.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -21,12 +21,14 @@
  */
 package org.jboss.test.osgi.jbosgi36.bundle;
 
+import org.jboss.test.osgi.jbosgi36.bundle.internal.SomeInternal;
+
 //$Id$
 
 public class SomeService 
 {
-  public String serviceEcho(String msg)
+  public String doStuff()
   {
-     return msg;
+     return SomeInternal.class.getName();
   }
 }

Modified: projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/junit/JBOSGI36Test.java
===================================================================
--- projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/Foo.java	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/Foo.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -25,8 +25,22 @@
 
 public class Foo implements FooMBean
 {
-	public String echo(String msg)
-	{
-		return msg;
-	}
+   public String echo(String msg)
+   {
+      return msg;
+   }
+
+   public String accessSomeService() throws ClassNotFoundException
+   {
+      ClassLoader loader = getClass().getClassLoader();
+      loader.loadClass("org.jboss.test.osgi.jbosgi36.bundle.SomeService");
+      return loader.toString();
+   }
+
+   public String accessSomeInternal() throws ClassNotFoundException
+   {
+      ClassLoader loader = getClass().getClassLoader();
+      loader.loadClass("org.jboss.test.osgi.jbosgi36.bundle.internal.SomeInternal");
+      return loader.toString();
+   }
 }

Modified: projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/FooMBean.java
===================================================================
--- projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/FooMBean.java	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/FooMBean.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -21,9 +21,19 @@
  */
 package org.jboss.test.osgi.jbosgi36.mbean;
 
-//$Id$
+// $Id$
 
+import javax.management.ObjectName;
+
+import org.jboss.osgi.spi.jmx.ObjectNameFactory;
+
 public interface FooMBean 
 {
-	String echo(String msg);
+   ObjectName OBJECT_NAME = ObjectNameFactory.create("jboss.osgi:test=jbosgi36");
+
+   String echo(String msg);
+   
+   String accessSomeService() throws ClassNotFoundException;
+   
+   String accessSomeInternal() throws ClassNotFoundException;
 }

Added: projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/jbosgi36-service.xml
===================================================================
--- projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/jbosgi36-service.xml	                        (rev 0)
+++ projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/jbosgi36-service.xml	2009-02-25 17:07:22 UTC (rev 84753)
@@ -0,0 +1,4 @@
+<server>
+   <mbean code="org.jboss.test.osgi.jbosgi36.mbean.Foo" name="jboss.osgi:test=jbosgi36">
+   </mbean>
+</server>
\ No newline at end of file


Property changes on: projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/META-INF/jbosgi36-service.xml
___________________________________________________________________
Name: svn:mergeinfo
   + 

Added: projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/jbosgi36.bnd
===================================================================
--- projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/jbosgi36.bnd	                        (rev 0)
+++ projects/jboss-osgi/trunk/testsuite/src/test/resources/jbosgi36/jbosgi36.bnd	2009-02-25 17:07:22 UTC (rev 84753)
@@ -0,0 +1,7 @@
+# bnd build -classpath target/test-classes -output target/test-libs/jbosgi36-bundle.jar src/test/resources/jbosgi36/jbosgi36.bnd
+
+Bundle-SymbolicName: jbosgi36
+Bundle-Activator: org.jboss.test.osgi.jbosgi36.bundle.SomeServiceActivator
+Export-Package: org.jboss.test.osgi.jbosgi36.bundle
+Private-Package: org.jboss.test.osgi.jbosgi36.bundle.internal
+




More information about the jboss-cvs-commits mailing list
--- projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/junit/JBOSGI36Test.java	2009-02-25 16:51:44 UTC (rev 84752)
+++ projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/junit/JBOSGI36Test.java	2009-02-25 17:07:22 UTC (rev 84753)
@@ -28,11 +28,10 @@
 import org.jboss.osgi.spi.jmx.MBeanProxy;
 import org.jboss.osgi.spi.junit.IntegrationTestCase;
 import org.jboss.osgi.spi.junit.IntegrationTestSetup;
-import org.jboss.test.osgi.service.microcontainer.FooMBean;
-import org.jboss.test.osgi.service.microcontainer.MBeanTestService;
+import org.jboss.test.osgi.jbosgi36.mbean.FooMBean;
 
 /**
  * Bundle classes leak into system classloader
  * 
  * https://jira.jboss.org/jira/browse/JBOSGI-36
  * 
@@ -41,14 +40,54 @@
  */
 public class JBOSGI36Test extends IntegrationTestCase
 {
-  public static Test suite()
-  {
-    return new IntegrationTestSetup(JBOSGI36Test.class, "jbosgi36-bundle.jar");
-  }
+   public static Test suite()
+   {
+      return new IntegrationTestSetup(JBOSGI36Test.class, "jbosgi36-bundle.jar, jbosgi36-service.jar");
+   }
 
-  public void testAccess() throws Exception
-  {
-    //FooMBean foo = (FooMBean)MBeanProxy.get(FooMBean.class, MBeanTestService.OBJECT_NAME, getServer());
-    //assertEquals("hello", foo.echo("hello"));
-  }
+   public void testAccessMBean() throws Exception
+   {
+      FooMBean foo = (FooMBean)MBeanProxy.get(FooMBean.class, FooMBean.OBJECT_NAME, getServer());
+      assertEquals("hello", foo.echo("hello"));
+   }
+
+   public void testAccessSomeService() throws Exception
+   {
+      if (true)
+      {
+         System.out.println("FIXME: [JBOSGI-36] Bundle classes leak into system classloader");
+         return;
+      }
+
+      FooMBean foo = (FooMBean)MBeanProxy.get(FooMBean.class, FooMBean.OBJECT_NAME, getServer());
+      try
+      {
+         foo.accessSomeService();
+         fail("ClassNotFoundException expected");
+      }
+      catch (ClassNotFoundException ex)
+      {
+         // expected
+      }
+   }
+
+   public void testAccessSomeInternal() throws Exception
+   {
+      if (true)
+      {
+         System.out.println("FIXME: [JBOSGI-36] Bundle classes leak into system classloader");
+         return;
+      }
+
+      FooMBean foo = (FooMBean)MBeanProxy.get(FooMBean.class, FooMBean.OBJECT_NAME, getServer());
+      try
+      {
+         foo.accessSomeInternal();
+         fail("ClassNotFoundException expected");
+      }
+      catch (ClassNotFoundException ex)
+      {
+         // expected
+      }
+   }
 }
\ No newline at end of file
@@ -28,11 +28,10 @@
 
 /**
- * Bundle classes leak into system classloader
+ * [JBOSGI-36] Bundle classes leak into system classloader
  * 
  * https://jira.jboss.org/jira/browse/JBOSGI-36

Modified: projects/jboss-osgi/trunk/testsuite/src/test/java/org/jboss/test/osgi/jbosgi36/mbean/Foo.java
===================================================================